<a href="home">
    <img src="https://static.dev.aws.cyber-boardroom.com/cbr-static/latest/assets/cbr/cbr-logo-beta.png" height="67" class="dark-logo"  style="margin: 10px"/>
</a>

<div class="alert alert-warning alert-dismissible fade show" role="alert">
    <h4 class="alert-heading">Important Note</h4>
    <p>Don't use any private or confidential data in the chats.
        There is no control over what happens inside the LLM platforms used,
        and all chat thread content is publicly available.</p>
</div>